==> haskell-conduit-parse-0.2.1.1-140-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-5aZK5mLTWcisCsaEWIG48
key:                  conduit-parse-0.2.1.1-5aZK5mLTWcisCsaEWIG48
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  eb9f81124c9d8dab22679cb535f3f5eb
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-5aZK5mLTWcisCsaEWIG48
depends:
    base-4.16.4.0 conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh
    dlist-1.0-HCxoMn9TirQDgPCFxho7O mtl-2.2.2
    parsers-0.12.11-BNeFON4lnWjK9sQVv7NnxL
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL
    safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-157-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-22oidjwb8Jj2NfoqWGmWpb
key:                  conduit-parse-0.2.1.1-22oidjwb8Jj2NfoqWGmWpb
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  889b5fd128e14a2051da21c91f98a4e2
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-22oidjwb8Jj2NfoqWGmWpb
depends:
    base-4.16.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    dlist-1.0-LNr75TD4CZoKEEzkBmhWjA mtl-2.2.2
    parsers-0.12.11-GQJpRLe968oESf6mSDWSbn
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
